summaryrefslogtreecommitdiffstats
path: root/xlators/cluster/afr/src/afr-common.c
diff options
context:
space:
mode:
Diffstat (limited to 'xlators/cluster/afr/src/afr-common.c')
-rw-r--r--xlators/cluster/afr/src/afr-common.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/xlators/cluster/afr/src/afr-common.c b/xlators/cluster/afr/src/afr-common.c
index 8720f8ab7..c00c80b9f 100644
--- a/xlators/cluster/afr/src/afr-common.c
+++ b/xlators/cluster/afr/src/afr-common.c
@@ -1773,8 +1773,9 @@ afr_error_more_important (int32_t old_errno, int32_t new_errno)
if (old_errno == ESTALE)
ret = _gf_false;
- /* Nothing should overwrite ENOENT, except ESTALE */
- else if ((old_errno == ENOENT) && (new_errno != ESTALE))
+ /* Nothing should overwrite ENOENT, except ESTALE/EIO*/
+ else if ((old_errno == ENOENT) && (new_errno != ESTALE)
+ && (new_errno != EIO))
ret = _gf_false;
return ret;